@@ -5,10 +5,12 @@
 //
 
 #include "sot/tools/kinematic-planner.hh"
+
 #include <dynamic-graph/command-bind.h>
+#include <time.h>
+
 #include <fstream>
 #include <sstream>
-#include <time.h>
 namespace dynamicgraph {
 namespace sot {
 namespace tools {
@@ -46,9 +48,11 @@ KinematicPlanner::KinematicPlanner(const std::string& name)
       "        - INT: Number of Time Steps in one 1.6 s \n"
       "        - INT: Number of periodic sources 1 \n"
       "        - INT: Number of periodic sources 2 \n"
-      "        - STRING: Path of the directory from where parameters can be loaded \n"
+      "        - STRING: Path of the directory from where parameters can be "
+      "loaded \n"
       "\n";
-  addCommand("setParams", dynamicgraph::command::makeCommandVoid3(*this, &KinematicPlanner::setParams, docstring1));
+  addCommand("setParams", dynamicgraph::command::makeCommandVoid3(
+                              *this, &KinematicPlanner::setParams, docstring1));
 
   // runKinematicPlanner
   const std::string docstring2 =
@@ -60,7 +64,10 @@ KinematicPlanner::KinematicPlanner(const std::string& name)
       "\n";
   addCommand("runKinematicPlanner",
              dynamicgraph::command::makeCommandVoid0(
-                 *this, (void (KinematicPlanner::*)(void)) & KinematicPlanner::runKinematicPlanner, docstring2));
+                 *this,
+                 (void(KinematicPlanner::*)(void)) &
+                     KinematicPlanner::runKinematicPlanner,
+                 docstring2));
   parametersSet = false;
 
   // std::string dir = "/local/rbudhira/git/proyan/sot-tools/src/params2";
@@ -74,8 +81,8 @@ KinematicPlanner::KinematicPlanner(const std::string& name)
 KinematicPlanner::~KinematicPlanner(void) {
   sotDEBUGIN(15);
 
-  for (std::list<SignalBase<int>*>::iterator iter = genericSignalRefs.begin(); iter != genericSignalRefs.end();
-       ++iter) {
+  for (std::list<SignalBase<int>*>::iterator iter = genericSignalRefs.begin();
+       iter != genericSignalRefs.end(); ++iter) {
     SignalBase<int>* sigPtr = *iter;
     delete sigPtr;
   }
@@ -93,7 +100,8 @@ void writeToFile(Eigen::DenseBase<Derived>& inMatrix, std::string& filePath) {
 }  // namespace
 
 template <typename Derived>
-void KinematicPlanner::read2DArray(std::string& fileName, Eigen::DenseBase<Derived>& outArr) {
+void KinematicPlanner::read2DArray(std::string& fileName,
+                                   Eigen::DenseBase<Derived>& outArr) {
   sotDEBUGIN(5);
   std::ifstream fileStream(fileName.c_str());
   std::string curLine;
@@ -114,7 +122,8 @@ void KinematicPlanner::read2DArray(std::string& fileName, Eigen::DenseBase<Deriv
   return;
 }
 
-void KinematicPlanner::setParams(const double& _distanceToDrawer, const double& _objectPositionInDrawer,
+void KinematicPlanner::setParams(const double& _distanceToDrawer,
+                                 const double& _objectPositionInDrawer,
                                  const std::string& dir) {
   sotDEBUGIN(5);
 
@@ -144,16 +153,19 @@ void KinematicPlanner::setParams(const double& _distanceToDrawer, const double&
 
   // Periodic Weights
   wPeriodic1.resize(nSources1);
-  for (int i = 0; i < nSources1; i++) wPeriodic1.at(i).resize(nJoints, nGaitCycles);
+  for (int i = 0; i < nSources1; i++)
+    wPeriodic1.at(i).resize(nJoints, nGaitCycles);
 
   wPeriodic2.resize(nSources2);
-  for (int i = 0; i < nSources2; i++) wPeriodic2.at(i).resize(nJoints, nGaitCycles);
+  for (int i = 0; i < nSources2; i++)
+    wPeriodic2.at(i).resize(nJoints, nGaitCycles);
 
   // Mean joint angles
   mJointAngle.resize(nJoints, nGaitCycles);
 
   loadSourceDelays(dir);
-  dynamicgraph::Vector goalsNew = createSubGoals(_distanceToDrawer, _objectPositionInDrawer);
+  dynamicgraph::Vector goalsNew =
+      createSubGoals(_distanceToDrawer, _objectPositionInDrawer);
   goalAdaption(goalsNew, dir);
   delaySources();
 
@@ -162,8 +174,11 @@ void KinematicPlanner::setParams(const double& _distanceToDrawer, const double&
   return;
 }
 
-void KinematicPlanner::loadTrainingParams(const std::string& dir, dynamicgraph::Matrix& q, dynamicgraph::Matrix& beta3,
-                                          Eigen::ArrayXd& mwwn, double& sigma2, int& N, int& K) {
+void KinematicPlanner::loadTrainingParams(const std::string& dir,
+                                          dynamicgraph::Matrix& q,
+                                          dynamicgraph::Matrix& beta3,
+                                          Eigen::ArrayXd& mwwn, double& sigma2,
+                                          int& N, int& K) {
   Eigen::Vector3d sigmaSqNK;
   std::string fileName = dir + "/" + "sigmaSqNK";
   read2DArray<Eigen::Vector3d>(fileName, sigmaSqNK);
@@ -294,7 +309,8 @@ void KinematicPlanner::delaySources() {
   // Do the FFT Source1
   Eigen::ArrayXXcd pSourceInFreq(nTimeSteps, nSources1);
   for (int cur_src = 0; cur_src < nSources1; cur_src++) {
-    pSourceInFreq.matrix().col(cur_src) = fft.fwd(pSource1.matrix().col(cur_src));
+    pSourceInFreq.matrix().col(cur_src) =
+        fft.fwd(pSource1.matrix().col(cur_src));
   }
 
   // Do the Delay
@@ -302,8 +318,10 @@ void KinematicPlanner::delaySources() {
     Eigen::ArrayXXd pSourceDelayedJoint(nTimeSteps, nSources1);
     for (int cur_src = 0; cur_src < nSources1; cur_src++) {
       // DelayedFt = Source(w) * exp^(V*pDelay1(joint, source))
-      const Eigen::ArrayXcd delayedFT = pSourceInFreq.col(cur_src) * (V * pDelay1(cJ, cur_src)).exp();
-      //(V*pDelay1(cT*nJoints+cJ, cur_src)).unaryExpr<std::complex(*)(std::complex)>(&std::exp);
+      const Eigen::ArrayXcd delayedFT =
+          pSourceInFreq.col(cur_src) * (V * pDelay1(cJ, cur_src)).exp();
+      //(V*pDelay1(cT*nJoints+cJ,
+      // cur_src)).unaryExpr<std::complex(*)(std::complex)>(&std::exp);
       // FFT Inv
       pSourceDelayedJoint.matrix().col(cur_src) = fft.inv(delayedFT.matrix());
     }
@@ -313,7 +331,8 @@ void KinematicPlanner::delaySources() {
   // Do the FFT Source 2
   pSourceInFreq.resize(Eigen::NoChange, nSources2);
   for (int cur_src = 0; cur_src < nSources2; cur_src++) {
-    pSourceInFreq.matrix().col(cur_src) = fft.fwd(pSource2.matrix().col(cur_src));
+    pSourceInFreq.matrix().col(cur_src) =
+        fft.fwd(pSource2.matrix().col(cur_src));
   }
 
   // Do the Delay
@@ -321,8 +340,10 @@ void KinematicPlanner::delaySources() {
     Eigen::ArrayXXd pSourceDelayedJoint(nTimeSteps, nSources2);
     for (int cur_src = 0; cur_src < nSources2; cur_src++) {
       // DelayedFt = Source(w) * exp^(V*pDelay1(joint, source))
-      const Eigen::ArrayXcd delayedFT = pSourceInFreq.col(cur_src) * (V * pDelay2(cJ, cur_src)).exp();
-      //(V*pDelay2(cT*nJoints+cJ, cur_src)).unaryExpr<std::complex(*)(std::complex)>(&std::exp);
+      const Eigen::ArrayXcd delayedFT =
+          pSourceInFreq.col(cur_src) * (V * pDelay2(cJ, cur_src)).exp();
+      //(V*pDelay2(cT*nJoints+cJ,
+      // cur_src)).unaryExpr<std::complex(*)(std::complex)>(&std::exp);
       // FFT Inv
       pSourceDelayedJoint.matrix().col(cur_src) = fft.inv(delayedFT.matrix());
     }
@@ -360,21 +381,27 @@ void KinematicPlanner::blending() {
           // Not for the first step
           // non periodic source intermediate value
           Eigen::ArrayXd wnpbeg =
-              (npSource(nTimeSteps - 1) * wNonPeriodic.col(cG - 1) + npSource(0) * wNonPeriodic.col(cG)) / 2;
+              (npSource(nTimeSteps - 1) * wNonPeriodic.col(cG - 1) +
+               npSource(0) * wNonPeriodic.col(cG)) /
+              2;
           // interpolation weight
           double ww = (std::sin(t / (nTimeSteps / 10) * pi / 2) + 1) / 2;
-          wCurrent = (2 * ww - 1) * wNonPeriodic.col(cG) + (1 - (2 * ww - 1)) * wnpbeg;
-          mJointAngleCurrent = ww * mJointAngle.col(cG) + (1 - ww) * mJointAngle.col(cG - 1);
+          wCurrent =
+              (2 * ww - 1) * wNonPeriodic.col(cG) + (1 - (2 * ww - 1)) * wnpbeg;
+          mJointAngleCurrent =
+              ww * mJointAngle.col(cG) + (1 - ww) * mJointAngle.col(cG - 1);
 
           for (int cSrc1 = 0; cSrc1 < nSources1; cSrc1++) {
             Eigen::ArrayXd intWeightCSrc =
-                ww * wPeriodic1.at(cSrc1).col(cG) + (1 - ww) * wPeriodic1.at(cSrc1).col(cG - 1);
+                ww * wPeriodic1.at(cSrc1).col(cG) +
+                (1 - ww) * wPeriodic1.at(cSrc1).col(cG - 1);
             currentWeight1.push_back(intWeightCSrc);
           }
 
           for (int cSrc2 = 0; cSrc2 < nSources2; cSrc2++) {
             Eigen::ArrayXd intWeightCSrc =
-                ww * wPeriodic2.at(cSrc2).col(cG) + (1 - ww) * wPeriodic2.at(cSrc2).col(cG - 1);
+                ww * wPeriodic2.at(cSrc2).col(cG) +
+                (1 - ww) * wPeriodic2.at(cSrc2).col(cG - 1);
             currentWeight2.push_back(intWeightCSrc);
           }
         }
@@ -386,21 +413,27 @@ void KinematicPlanner::blending() {
           // Not for the last gait cycle
           specialInterpolatedWeight = true;
           Eigen::ArrayXd wnpEnd =
-              -(npSource(nTimeSteps - 1) * wNonPeriodic.col(cG) + npSource(0) * wNonPeriodic.col(cG + 1)) / 2;
-          double ww = (std::sin((t - nTimeSteps) / (nTimeSteps / 10) * pi / 2) + 1) / 2;
+              -(npSource(nTimeSteps - 1) * wNonPeriodic.col(cG) +
+                npSource(0) * wNonPeriodic.col(cG + 1)) /
+              2;
+          double ww =
+              (std::sin((t - nTimeSteps) / (nTimeSteps / 10) * pi / 2) + 1) / 2;
           wCurrent = (1 - 2 * ww) * wNonPeriodic.col(cG) + 2 * ww * wnpEnd;
-          mJointAngleCurrent = (1 - ww) * mJointAngle.col(cG) + ww * mJointAngle.col(cG + 1);
+          mJointAngleCurrent =
+              (1 - ww) * mJointAngle.col(cG) + ww * mJointAngle.col(cG + 1);
 
           for (int cSrc1 = 0; cSrc1 < nSources1; cSrc1++) {
             Eigen::ArrayXd intWeightCSrc =
-                (1 - ww) * wPeriodic1.at(cSrc1).col(cG) + ww * wPeriodic1.at(cSrc1).col(cG + 1);
+                (1 - ww) * wPeriodic1.at(cSrc1).col(cG) +
+                ww * wPeriodic1.at(cSrc1).col(cG + 1);
 
             currentWeight1.push_back(intWeightCSrc);
           }
 
           for (int cSrc2 = 0; cSrc2 < nSources2; cSrc2++) {
             Eigen::ArrayXd intWeightCSrc =
-                (1 - ww) * wPeriodic2.at(cSrc2).col(cG) + ww * wPeriodic2.at(cSrc2).col(cG + 1);
+                (1 - ww) * wPeriodic2.at(cSrc2).col(cG) +
+                ww * wPeriodic2.at(cSrc2).col(cG + 1);
             currentWeight2.push_back(intWeightCSrc);
           }
         }  //(cG!=nGaitCycles-1)
@@ -410,18 +443,22 @@ void KinematicPlanner::blending() {
       for (int cJ = 0; cJ < nJoints; cJ++) {
         if (specialInterpolatedWeight) {
           for (int cSrc1 = 0; cSrc1 < nSources1; cSrc1++)
-            allJointsOneGaitCycle(t, cJ) += pSourceDelayed1.at(cJ)(t, cSrc1) * currentWeight1.at(cSrc1)(cJ);
+            allJointsOneGaitCycle(t, cJ) +=
+                pSourceDelayed1.at(cJ)(t, cSrc1) * currentWeight1.at(cSrc1)(cJ);
           for (int cSrc2 = 0; cSrc2 < nSources2; cSrc2++)
-            allJointsOneGaitCycle(t, cJ) += pSourceDelayed2.at(cJ)(t, cSrc2) * currentWeight2.at(cSrc2)(cJ);
+            allJointsOneGaitCycle(t, cJ) +=
+                pSourceDelayed2.at(cJ)(t, cSrc2) * currentWeight2.at(cSrc2)(cJ);
 
           allJointsOneGaitCycle(t, cJ) += npSource(t) * wCurrent(cJ);
           allJointsOneGaitCycle(t, cJ) += mJointAngleCurrent(cJ);
 
         } else {
           for (int cSrc1 = 0; cSrc1 < nSources1; cSrc1++)
-            allJointsOneGaitCycle(t, cJ) += pSourceDelayed1.at(cJ)(t, cSrc1) * wPeriodic1.at(cSrc1)(cJ, cG);
+            allJointsOneGaitCycle(t, cJ) +=
+                pSourceDelayed1.at(cJ)(t, cSrc1) * wPeriodic1.at(cSrc1)(cJ, cG);
           for (int cSrc2 = 0; cSrc2 < nSources2; cSrc2++)
-            allJointsOneGaitCycle(t, cJ) += pSourceDelayed2.at(cJ)(t, cSrc2) * wPeriodic2.at(cSrc2)(cJ, cG);
+            allJointsOneGaitCycle(t, cJ) +=
+                pSourceDelayed2.at(cJ)(t, cSrc2) * wPeriodic2.at(cSrc2)(cJ, cG);
 
           allJointsOneGaitCycle(t, cJ) += npSource(t) * wNonPeriodic(cJ, cG);
           allJointsOneGaitCycle(t, cJ) += mJointAngle(cJ, cG);
@@ -445,7 +482,8 @@ void KinematicPlanner::blending() {
       }
     }
 
-    allJointsAllGaitCycle.middleRows(cG * nTimeSteps, nTimeSteps) = allJointsOneGaitCycle;
+    allJointsAllGaitCycle.middleRows(cG * nTimeSteps, nTimeSteps) =
+        allJointsOneGaitCycle;
     allJointsOneGaitCycle.setZero();
   }  // Finish Iterate through gait cycles
 
@@ -453,53 +491,58 @@ void KinematicPlanner::blending() {
   Eigen::ArrayXXd allJointsAllGaitCycleNew(nTimeSteps * nGaitCycles, 58);
 
   // Time Stamps
-  allJointsAllGaitCycleNew.col(0) = Eigen::ArrayXd::LinSpaced(nTimeSteps * nGaitCycles, 1, nTimeSteps * nGaitCycles);
+  allJointsAllGaitCycleNew.col(0) = Eigen::ArrayXd::LinSpaced(
+      nTimeSteps * nGaitCycles, 1, nTimeSteps * nGaitCycles);
 
   // Map calculated traj to joint kinematic chain.
-  allJointsAllGaitCycleNew.col(1) = allJointsAllGaitCycle.col(0);    // XVel
-  allJointsAllGaitCycleNew.col(2) = allJointsAllGaitCycle.col(1);    // YVel
-  allJointsAllGaitCycleNew.col(3).setZero();                         // Yaw vel =0
-  allJointsAllGaitCycleNew.col(4) = allJointsAllGaitCycle.col(2);    // Chest
-  allJointsAllGaitCycleNew.col(5) = allJointsAllGaitCycle.col(3);    // Chest
-  allJointsAllGaitCycleNew.col(6).setZero();                         // Head = 0
-  allJointsAllGaitCycleNew.col(7).setZero();                         // Head = 0
-  allJointsAllGaitCycleNew.col(8) = allJointsAllGaitCycle.col(4);    // LARM
-  allJointsAllGaitCycleNew.col(9) = allJointsAllGaitCycle.col(5);    // LARM
-  allJointsAllGaitCycleNew.col(10) = allJointsAllGaitCycle.col(6);   // LARM
-  allJointsAllGaitCycleNew.col(11) = allJointsAllGaitCycle.col(7);   // LARM
-  allJointsAllGaitCycleNew.col(12) = allJointsAllGaitCycle.col(8);   // LARM
-  allJointsAllGaitCycleNew.col(13) = allJointsAllGaitCycle.col(9);   // LARM
-  allJointsAllGaitCycleNew.col(14).setZero();                        // LARM = 10deg
+  allJointsAllGaitCycleNew.col(1) = allJointsAllGaitCycle.col(0);  // XVel
+  allJointsAllGaitCycleNew.col(2) = allJointsAllGaitCycle.col(1);  // YVel
+  allJointsAllGaitCycleNew.col(3).setZero();                       // Yaw vel =0
+  allJointsAllGaitCycleNew.col(4) = allJointsAllGaitCycle.col(2);  // Chest
+  allJointsAllGaitCycleNew.col(5) = allJointsAllGaitCycle.col(3);  // Chest
+  allJointsAllGaitCycleNew.col(6).setZero();                       // Head = 0
+  allJointsAllGaitCycleNew.col(7).setZero();                       // Head = 0
+  allJointsAllGaitCycleNew.col(8) = allJointsAllGaitCycle.col(4);  // LARM
+  allJointsAllGaitCycleNew.col(9) = allJointsAllGaitCycle.col(5);  // LARM
+  allJointsAllGaitCycleNew.col(10) = allJointsAllGaitCycle.col(6);  // LARM
+  allJointsAllGaitCycleNew.col(11) = allJointsAllGaitCycle.col(7);  // LARM
+  allJointsAllGaitCycleNew.col(12) = allJointsAllGaitCycle.col(8);  // LARM
+  allJointsAllGaitCycleNew.col(13) = allJointsAllGaitCycle.col(9);  // LARM
+  allJointsAllGaitCycleNew.col(14).setZero();  // LARM = 10deg
   allJointsAllGaitCycleNew.col(15) = allJointsAllGaitCycle.col(10);  // RARM
   allJointsAllGaitCycleNew.col(16) = allJointsAllGaitCycle.col(11);  // RARM
   allJointsAllGaitCycleNew.col(17) = allJointsAllGaitCycle.col(12);  // RARM
   allJointsAllGaitCycleNew.col(18) = allJointsAllGaitCycle.col(13);  // RARM
   allJointsAllGaitCycleNew.col(19) = allJointsAllGaitCycle.col(14);  // RARM
   allJointsAllGaitCycleNew.col(20) = allJointsAllGaitCycle.col(15);  // RARM
-  allJointsAllGaitCycleNew.col(21).setZero();                        // RARM = 10deg
+  allJointsAllGaitCycleNew.col(21).setZero();  // RARM = 10deg
 
   allJointsAllGaitCycleNew.middleCols<18>(4) *= 180 / pi;  // Convert to Degrees
-  allJointsAllGaitCycleNew.col(14).setConstant(10);        // LARM Final joint = 10deg
-  allJointsAllGaitCycleNew.col(21).setConstant(10);        // RARM Final Joint = 10deg
+  allJointsAllGaitCycleNew.col(14).setConstant(10);  // LARM Final joint = 10deg
+  allJointsAllGaitCycleNew.col(21).setConstant(10);  // RARM Final Joint = 10deg
 
   // Generate q_dot vectors
   for (int i = 0; i < allJointsAllGaitCycleNew.rows() - 1; i++)
     allJointsAllGaitCycleNew.row(i).segment<18>(22) =
-        allJointsAllGaitCycleNew.row(i + 1).segment<18>(4) - allJointsAllGaitCycleNew.row(i).segment<18>(4);
+        allJointsAllGaitCycleNew.row(i + 1).segment<18>(4) -
+        allJointsAllGaitCycleNew.row(i).segment<18>(4);
 
   allJointsAllGaitCycleNew.row(nTimeSteps * nGaitCycles - 1).segment<18>(22) =
-      allJointsAllGaitCycleNew.row(nTimeSteps * nGaitCycles - 2).segment<18>(22);
+      allJointsAllGaitCycleNew.row(nTimeSteps * nGaitCycles - 2)
+          .segment<18>(22);
 
   savitzkyGolayFilter(allJointsAllGaitCycleNew.leftCols<40>(), 6, 51);
 
   // Generate q_dot_dot vectors
   for (int i = 0; i < allJointsAllGaitCycleNew.rows() - 1; i++)
     allJointsAllGaitCycleNew.row(i).segment<18>(40) =
-        (allJointsAllGaitCycleNew.row(i + 1).segment<18>(22) - allJointsAllGaitCycleNew.row(i).segment<18>(22)) *
+        (allJointsAllGaitCycleNew.row(i + 1).segment<18>(22) -
+         allJointsAllGaitCycleNew.row(i).segment<18>(22)) *
         200;  // 200fps
 
   allJointsAllGaitCycleNew.row(nTimeSteps * nGaitCycles - 1).segment<18>(40) =
-      allJointsAllGaitCycleNew.row(nTimeSteps * nGaitCycles - 2).segment<18>(40);
+      allJointsAllGaitCycleNew.row(nTimeSteps * nGaitCycles - 2)
+          .segment<18>(40);
 }
 
 void KinematicPlanner::smoothEnds(Eigen::Ref<Eigen::ArrayXd> tr) {
@@ -529,18 +572,23 @@ void KinematicPlanner::bSplineInterpolate(Eigen::ArrayXXd& tr, int factor) {
 
   Eigen::RowVectorXd x_vec(nTimeSteps * nGaitCycles);
   Eigen::RowVectorXd x_vec_new(nTimeSteps * nGaitCycles * factor);
-  for (int i = 0; i < nTimeSteps * nGaitCycles; i++) x_vec(i) = i / (nTimeSteps * nGaitCycles);
-  for (int i = 0; i < nTimeSteps * nGaitCycles * factor; i++) x_vec_new(i) = i / (nTimeSteps * nGaitCycles * factor);
+  for (int i = 0; i < nTimeSteps * nGaitCycles; i++)
+    x_vec(i) = i / (nTimeSteps * nGaitCycles);
+  for (int i = 0; i < nTimeSteps * nGaitCycles * factor; i++)
+    x_vec_new(i) = i / (nTimeSteps * nGaitCycles * factor);
 
   for (int cJ = 0; cJ < nJoints; cJ++) {
     Eigen::Spline<double, splDim> spl =
-        Eigen::SplineFitting<Eigen::Spline<double, splDim> >::Interpolate(trCopy.col(cJ).transpose(), splDeg, x_vec);
-    for (int t = 0; t < nTimeSteps * nGaitCycles * factor; t++) tr(t, cJ) = spl(x_vec_new(t))(0);
+        Eigen::SplineFitting<Eigen::Spline<double, splDim> >::Interpolate(
+            trCopy.col(cJ).transpose(), splDeg, x_vec);
+    for (int t = 0; t < nTimeSteps * nGaitCycles * factor; t++)
+      tr(t, cJ) = spl(x_vec_new(t))(0);
   }
   return;
 }
 
-void KinematicPlanner::goalAdaption(dynamicgraph::Vector& goals, const std::string& dir) {
+void KinematicPlanner::goalAdaption(dynamicgraph::Vector& goals,
+                                    const std::string& dir) {
   ////////////////////////////////////////////////////////////////////
   //     load for the first 2 steps
 
@@ -565,9 +613,11 @@ void KinematicPlanner::goalAdaption(dynamicgraph::Vector& goals, const std::stri
       X.col(0) = q.col(0) - Eigen::MatrixXd::Ones(q.rows(), 1) * test_point(0);
       X.col(1) = q.col(1) - Eigen::MatrixXd::Ones(q.rows(), 1) * test_point(1);
       X.col(2) = Eigen::MatrixXd::Ones(q.rows(), 1);
-      Eigen::VectorXd _expdiag = (-(((X * X.transpose()).diagonal().matrix()) / sigma2)).exp();
+      Eigen::VectorXd _expdiag =
+          (-(((X * X.transpose()).diagonal().matrix()) / sigma2)).exp();
       Eigen::MatrixXd Wkern = _expdiag.asDiagonal();
-      M(k) = (((X.transpose() * Wkern * X) * X.transpose() * Wkern).inverse() * beta3.col(k))(q.cols());
+      M(k) = (((X.transpose() * Wkern * X) * X.transpose() * Wkern).inverse() *
+              beta3.col(k))(q.cols());
     }
 
     Eigen::ArrayXd wwn = M + mwwn;
@@ -576,17 +626,25 @@ void KinematicPlanner::goalAdaption(dynamicgraph::Vector& goals, const std::stri
     // first two steps
     for (int j = 0; j < 2; j++) {
       for (int cs1 = 0; cs1 < nSources1; cs1++) {
-        wPeriodic1.at(cs1).col(j) = wwn.segment(j * (nJoints * (nSources1 + nSources2 + 2)) + cs1 * nJoints, nJoints);
+        wPeriodic1.at(cs1).col(j) = wwn.segment(
+            j * (nJoints * (nSources1 + nSources2 + 2)) + cs1 * nJoints,
+            nJoints);
       }
       for (int cs2 = 0; cs2 < nSources2; cs2++) {
         wPeriodic2.at(cs2).col(j) =
-            wwn.segment(j * (nJoints * (nSources1 + nSources2 + 2)) + nJoints * nSources1 + cs2 * nJoints, nJoints);
+            wwn.segment(j * (nJoints * (nSources1 + nSources2 + 2)) +
+                            nJoints * nSources1 + cs2 * nJoints,
+                        nJoints);
       }
       wNonPeriodic.col(j) =
-          wwn.segment(j * (nJoints * (nSources1 + nSources2 + 2)) + nJoints * (nSources1 + nSources2), nJoints);
+          wwn.segment(j * (nJoints * (nSources1 + nSources2 + 2)) +
+                          nJoints * (nSources1 + nSources2),
+                      nJoints);
 
       mJointAngle.col(j) =
-          wwn.segment(j * (nJoints * (nSources1 + nSources2 + 2)) + nJoints * (nSources1 + nSources2 + 1), nJoints);
+          wwn.segment(j * (nJoints * (nSources1 + nSources2 + 2)) +
+                          nJoints * (nSources1 + nSources2 + 1),
+                      nJoints);
     }
   }  // local scope01
 
@@ -612,9 +670,11 @@ void KinematicPlanner::goalAdaption(dynamicgraph::Vector& goals, const std::stri
       X.col(0) = q.col(0) - Eigen::MatrixXd::Ones(q.rows(), 1) * test_point(0);
       X.col(1) = q.col(1) - Eigen::MatrixXd::Ones(q.rows(), 1) * test_point(1);
       X.col(2) = Eigen::MatrixXd::Ones(q.rows(), 1);
-      Eigen::VectorXd _expdiag = (-(((X * X.transpose()).diagonal().matrix()) / sigma2)).exp();
+      Eigen::VectorXd _expdiag =
+          (-(((X * X.transpose()).diagonal().matrix()) / sigma2)).exp();
       Eigen::MatrixXd Wkern = _expdiag.asDiagonal();
-      M(k) = (((X.transpose() * Wkern * X) * X.transpose() * Wkern).inverse() * beta3.col(k))(q.cols());
+      M(k) = (((X.transpose() * Wkern * X) * X.transpose() * Wkern).inverse() *
+              beta3.col(k))(q.cols());
     }
 
     Eigen::ArrayXd wwn = M + mwwn;
@@ -625,10 +685,13 @@ void KinematicPlanner::goalAdaption(dynamicgraph::Vector& goals, const std::stri
       wPeriodic1.at(cs1).col(2) = wwn.segment(cs1 * nJoints, nJoints);
     }
     for (int cs2 = 0; cs2 < nSources2; cs2++) {
-      wPeriodic2.at(cs2).col(2) = wwn.segment(nJoints * nSources1 + cs2 * nJoints, nJoints);
+      wPeriodic2.at(cs2).col(2) =
+          wwn.segment(nJoints * nSources1 + cs2 * nJoints, nJoints);
     }
-    wNonPeriodic.col(2) = wwn.segment(nJoints * (nSources1 + nSources2), nJoints);
-    mJointAngle.col(2) = wwn.segment(nJoints * (nSources1 + nSources2 + 1), nJoints);
+    wNonPeriodic.col(2) =
+        wwn.segment(nJoints * (nSources1 + nSources2), nJoints);
+    mJointAngle.col(2) =
+        wwn.segment(nJoints * (nSources1 + nSources2 + 1), nJoints);
 
   }  // local scope3
 
@@ -655,10 +718,12 @@ void KinematicPlanner::goalAdaption(dynamicgraph::Vector& goals, const std::stri
       X.col(0) = q.col(0) - Eigen::MatrixXd::Ones(q.rows(), 1) * test_point(0);
       X.col(1) = q.col(1) - Eigen::MatrixXd::Ones(q.rows(), 1) * test_point(1);
       X.col(2) = Eigen::MatrixXd::Ones(q.rows(), 1);
-      Eigen::VectorXd _expdiag = (-(((X * X.transpose()).diagonal().matrix()) / sigma2)).exp();
+      Eigen::VectorXd _expdiag =
+          (-(((X * X.transpose()).diagonal().matrix()) / sigma2)).exp();
       Eigen::MatrixXd Wkern = _expdiag.asDiagonal();
 
-      M(k) = (((X.transpose() * Wkern * X) * X.transpose() * Wkern).inverse() * beta3.col(k))(q.cols());
+      M(k) = (((X.transpose() * Wkern * X) * X.transpose() * Wkern).inverse() *
+              beta3.col(k))(q.cols());
     }
 
     Eigen::ArrayXd wwn = M + mwwn;
@@ -668,30 +733,38 @@ void KinematicPlanner::goalAdaption(dynamicgraph::Vector& goals, const std::stri
       wPeriodic1.at(cs1).col(3) = wwn.segment(cs1 * nJoints, nJoints);
     }
     for (int cs2 = 0; cs2 < nSources2; cs2++) {
-      wPeriodic2.at(cs2).col(3) = wwn.segment(nJoints * nSources1 + cs2 * nJoints, nJoints);
+      wPeriodic2.at(cs2).col(3) =
+          wwn.segment(nJoints * nSources1 + cs2 * nJoints, nJoints);
     }
-    wNonPeriodic.col(3) = wwn.segment(nJoints * (nSources1 + nSources2), nJoints);
-    mJointAngle.col(3) = wwn.segment(nJoints * (nSources1 + nSources2 + 1), nJoints);
+    wNonPeriodic.col(3) =
+        wwn.segment(nJoints * (nSources1 + nSources2), nJoints);
+    mJointAngle.col(3) =
+        wwn.segment(nJoints * (nSources1 + nSources2 + 1), nJoints);
   }  // local scope4
 }
 
-void KinematicPlanner::savitzkyGolayFilter(Eigen::Ref<Eigen::ArrayXXd> allJointTraj, int polyOrder, int frameSize) {
+void KinematicPlanner::savitzkyGolayFilter(
+    Eigen::Ref<Eigen::ArrayXXd> allJointTraj, int polyOrder, int frameSize) {
   assert(polyOrder < frameSize);
-  assert(frameSize <= allJointTraj.rows());  // Length of the inputs is >= frameSize
-  assert(frameSize % 2 == 1);                // frameSize must be odd
+  assert(frameSize <=
+         allJointTraj.rows());  // Length of the inputs is >= frameSize
+  assert(frameSize % 2 == 1);   // frameSize must be odd
 
   // Calc the projection matrix
 
   // Create the vandermonde matrix
   Eigen::ArrayXXd vanderArr(frameSize, polyOrder + 1);
   vanderArr.col(0).setOnes();
-  vanderArr.col(1) = Eigen::ArrayXd::LinSpaced(frameSize, -(frameSize - 1) / 2, (frameSize - 1) / 2);
-  for (int i = 2; i < polyOrder + 1; i++) vanderArr.col(i) = vanderArr.col(i - 1) * vanderArr.col(1);
+  vanderArr.col(1) = Eigen::ArrayXd::LinSpaced(frameSize, -(frameSize - 1) / 2,
+                                               (frameSize - 1) / 2);
+  for (int i = 2; i < polyOrder + 1; i++)
+    vanderArr.col(i) = vanderArr.col(i - 1) * vanderArr.col(1);
   sotDEBUG(15) << "Printing the VanderArr" << std::endl;
   sotDEBUG(15) << vanderArr << std::endl;
 
   // Cholesky factor and projection
-  Eigen::MatrixXd upperT = (vanderArr.matrix().transpose() * vanderArr.matrix()).llt().matrixU();
+  Eigen::MatrixXd upperT =
+      (vanderArr.matrix().transpose() * vanderArr.matrix()).llt().matrixU();
   sotDEBUG(15) << "Printing the Cholesky decomp" << std::endl;
   sotDEBUG(15) << upperT << std::endl;
   Eigen::MatrixXd A = vanderArr.matrix() * upperT.inverse();
@@ -704,17 +777,23 @@ void KinematicPlanner::savitzkyGolayFilter(Eigen::Ref<Eigen::ArrayXXd> allJointT
   for (int cJ = 0; cJ < allJointTraj.cols(); cJ++) {
     // transient on:
     Eigen::VectorXd yit =
-        (proj.bottomRows((frameSize + 1) / 2) * allJointTraj.matrix().col(cJ).head(frameSize).reverse()).reverse();
+        (proj.bottomRows((frameSize + 1) / 2) *
+         allJointTraj.matrix().col(cJ).head(frameSize).reverse())
+            .reverse();
 
     // steady state:
     Eigen::MatrixXd xb(frameSize, allJointTraj.rows() - frameSize + 1);
     for (int i = 0; i < allJointTraj.rows() - frameSize + 1; i++)
       xb.col(i) = allJointTraj.col(cJ).segment(i, frameSize);
-    Eigen::VectorXd yss = (proj.row((frameSize - 1) / 2) * xb.middleCols(1, xb.cols() - 2)).transpose();
+    Eigen::VectorXd yss =
+        (proj.row((frameSize - 1) / 2) * xb.middleCols(1, xb.cols() - 2))
+            .transpose();
 
     // transient off:
     Eigen::VectorXd yot =
-        (proj.topRows((frameSize + 1) / 2) * allJointTraj.matrix().col(cJ).tail(frameSize).reverse()).reverse();
+        (proj.topRows((frameSize + 1) / 2) *
+         allJointTraj.matrix().col(cJ).tail(frameSize).reverse())
+            .reverse();
 
     allJointTraj.col(cJ) << yit, yss, yot;
   }
@@ -734,8 +813,8 @@ int& KinematicPlanner::runKinematicPlanner(int& dummy, int time) {
   assert(parametersSet && "Set Parameters via setParams first");
   //    double distanceToDrawer = distToDrawerSIN.access(time);
   //    double objectPositionInDrawer = objectPositionInDrawerSIN.access(time);
-  //    dynamicgraph::Vector goalsNew = createSubGoals(distanceToDrawer,objectPositionInDrawer);
-  //    delaySources();
+  //    dynamicgraph::Vector goalsNew =
+  //    createSubGoals(distanceToDrawer,objectPositionInDrawer); delaySources();
   blending();
   return dummy;
 }
